@@ -382,6 +382,7 @@ bool MainApp::loadLevel(TriggerLevel &tl)
   tl.name = "Untitled";
   tl.comment = "";
   tl.author = "";
+  tl.targettime = "";
   
   TiXmlDocument xmlfile(tl.filename.c_str());
   TiXmlElement *rootelem = PUtil::loadRootElement(xmlfile, "level");
@@ -398,6 +399,15 @@ bool MainApp::loadLevel(TriggerLevel &tl)
   if (val) tl.comment = val;
   val = rootelem->Attribute("author");
   if (val) tl.author = val;
+  for (TiXmlElement *walk = rootelem->FirstChildElement();
+    walk; walk = walk->NextSiblingElement()) {
+    
+    if (!strcmp(walk->Value(), "race")) {
+      val = walk->Attribute("targettime");
+      if (val) tl.targettime = PUtil::formatTime(atof(val));
+
+    }
+  }
   
   return true;
 }
@@ -491,7 +501,6 @@ bool MainApp::loadAll()
   if (!(tex_end_screen = getSSTexture().loadTexture("/textures/splash/endgame.jpg"))) return false;
   
   if (!(tex_hud_life = getSSTexture().loadTexture("/textures/life_helmet.png"))) return false;
-  if (!(tex_hud_arrow = getSSTexture().loadTexture("/textures/arrow.png"))) return false;
   
   if (!(tex_detail = getSSTexture().loadTexture("/textures/detail.jpg"))) return false;
   if (!(tex_dirt = getSSTexture().loadTexture("/textures/dust.png"))) return false;
@@ -514,11 +523,11 @@ bool MainApp::loadAll()
   if (!(tex_hud_gear = getSSTexture().loadTexture("/textures/dial_gear.png"))) return false;
   
   if (cfg_enable_sound) {
-    if (!(aud_engine = getSSAudio().loadSample("/sounds/engine1.wav", false))) return false;
+    if (!(aud_engine = getSSAudio().loadSample("/sounds/engine.wav", false))) return false;
     if (!(aud_wind = getSSAudio().loadSample("/sounds/wind.wav", false))) return false;
-    if (!(aud_gearchange = getSSAudio().loadSample("/sounds/evo_sound/clank1.wav", false))) return false;
-    if (!(aud_gravel = getSSAudio().loadSample("/sounds/gravel2.wav", false))) return false;
-    if (!(aud_crash1 = getSSAudio().loadSample("/sounds/evo_sound/clank3.wav", false))) return false;
+    if (!(aud_gearchange = getSSAudio().loadSample("/sounds/gear.wav", false))) return false;
+    if (!(aud_gravel = getSSAudio().loadSample("/sounds/gravel.wav", false))) return false;
+    if (!(aud_crash1 = getSSAudio().loadSample("/sounds/bang.wav", false))) return false;
   }
   
   if (!loadLevelsAndEvents()) {
@@ -947,7 +956,7 @@ void MainApp::tickStateGame(float delta)
     if (vehic->getFlagGearChange()) {
       audinst.push_back(new PAudioInstance(aud_gearchange));
       audinst.back()->setPitch(1.0f + randm11*0.02f);
-      audinst.back()->setGain(0.4f);
+      audinst.back()->setGain(0.3f);
       audinst.back()->play();
     }
     
@@ -1175,6 +1184,7 @@ void MainApp::joyButtonEvent(int which, int button, bool down)
   }
 }
 
+#ifndef WIN32
 
 int main(int argc, char *argv[])
 {
@@ -1187,5 +1197,26 @@ int main(int argc, char *argv[])
   return ret;
 }
 
+#else
 
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+
+int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
+{
+    UNREFERENCED_PARAMETER(hInstance);
+    UNREFERENCED_PARAMETER(hPrevInstance);
+    UNREFERENCED_PARAMETER(lpCmdLine);
+    UNREFERENCED_PARAMETER(nCmdShow);
+
+  MainApp *game = new MainApp("Trigger", ".trigger");
+
+  int ret = game->run(0, nullptr);
+
+  delete game;
+
+  return ret;
+}
+
+#endif
 
